# Generated by Django 3.1.7 on 2021-03-26 22:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0004_drop_channels'),
    ]

    operations = [
        migrations.RenameField(
            model_name='notification',
            old_name='channels_json',
            new_name='channels',
        ),
    ]



# Generated by Django 3.1.7 on 2021-03-26 22:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0003_notification_channels_json'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='notification',
            name='channels',
        )
    ]



# Optional dependencies are wrapped in try/excepts to prevent
# ImportErrors if the user hasn't installed them
# Surely, there's a better way to handle this :/

try:
    from .rq import RQBackend as RQ  # noqa
except ImportError:
    pass
try:
    from .celery import CeleryBackend as Celery  # noqa
except ImportError:
    pass
try:
    from .django_channels import ChannelsBackend as Channels  # noqa
except ImportError:
    pass

from .synchronous import SynchronousBackend as Synchronous  # noqa



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-07-19 11:37
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0002_auto_20170718_1539'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='notification',
            options={'ordering': ('create_date',)},
        ),
    ]



# Generated by Django 3.1.7 on 2021-03-26 21:53

from django.db import migrations
import django_jsonfield_backport.models


def convert_strings_to_lists(apps, schema_editor):
    Notification = apps.get_model('notifications', 'Notification')
    for notification in Notification.objects.all():
        channels = notification.channels
        if channels:
            notification.channels_json = channels
        else:
            notification.channels = list()

        notification.save()


def reverse_convert_strings_to_lists(apps, schema_editor):
    Notification = apps.get_model('notifications', 'Notification')
    for notification in Notification.objects.all():
        notification.channels_json = list()
        notification.save()


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0002_django_jsonfield_backport'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='channels_json',
            field=django_jsonfield_backport.models.JSONField(default=list),
        ),

        migrations.RunPython(
            convert_strings_to_lists, reverse_convert_strings_to_lists
        )
    ]
